#include <cstddef>
#include "mymalloc.h"
#include "test.h"

// Heap redirection example. The "test.mac" file will set log breakpoints
// that prints calls to "OS_malloc", "OS_free", "OS_heap_init" and 
// "__call_ctors" in the Debug Log window.

extern "C" void __iar_dynamic_initialization(void);

Test::Test()
{
    a = new A();
}

Test::~Test()
{
    delete(a);
}

// Global Test class 
//
// tGlobal.a will be initialized when __iar_dynamic_initialization is called.
// Before __iar_dynamic_initialization is called, tGlobal.a will be 0x0.
// After __iar_dynamic_initialization is called, tGlobal.a will be set to
// a new instance of the A class (located on the "OS" heap).
static Test tGlobal;

int main()
{
    // 1. Init the RTOS heap
    OS_heap_init();
    
    // 2. Perform dynamic initializition (i.e. call global constructors)
    __iar_dynamic_initialization();

    Test t;
    
    return 0;
}
